==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/antistring/translations/antistring_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Tchat</translation>
    </message>
    <message>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Enable Antistring</source>
        <translation>Activer Antistring</translation>
    </message>
    <message>
        <source>Block message</source>
        <translation>Bloquer le message</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation>Admonition</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Journal</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Enregistrer le journal dans un fichier</translation>
    </message>
    <message>
        <source>Conditions</source>
        <translation>Conditions</translation>
    </message>
    <message>
        <source>Antistring notifications</source>
        <translation>Notifications Antistring</translation>
    </message>
</context>
<context>
    <name>Antistring</name>
    <message>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation>     DONNÉES ET TEMPS      ::   ID   ::    MESSAGE
</translation>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <source>Condition</source>
        <translation>Condition</translation>
    </message>
    <message>
        <source>Don&apos;t use</source>
        <translation>Ne pas utiliser</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Facteur</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajoutez</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Changez</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>AntistringNotification</name>
    <message>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <source>Your interlocutor send you love letter</source>
        <translation>Votre interlocuteur vous a envoyé une lettre d&apos;amour</translation>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/antistring/translations/antistring_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Tchat</translation>
    </message>
    <message>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Enable Antistring</source>
        <translation>Activer Antistring</translation>
    </message>
    <message>
        <source>Block message</source>
        <translation>Bloquer le message</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation>Admonition</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Journal</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Enregistrer le journal dans un fichier</translation>
    </message>
    <message>
        <source>Conditions</source>
        <translation>Conditions</translation>
    </message>
    <message>
        <source>Antistring notifications</source>
        <translation>Notifications Antistring</translation>
    </message>
</context>
<context>
    <name>Antistring</name>
    <message>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation>     DONNÉES ET TEMPS      ::   ID   ::    MESSAGE
</translation>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <source>Condition</source>
        <translation>Condition</translation>
    </message>
    <message>
        <source>Don&apos;t use</source>
        <translation>Ne pas utiliser</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Facteur</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajoutez</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Changez</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>AntistringNotification</name>
    <message>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <source>Your interlocutor send you love letter</source>
        <translation>Votre interlocuteur vous a envoyé une lettre d&apos;amour</translation>
    </message>
</context>
</TS>
